;-------------------------------------------------------------------
; Titel       : Print-Screen Funktion
; File        : PRINTSCREEN.EVS
;-------------------------------------------------------------------
; Compiler    : eigerScript
;
; System      : eigergraphics.com; FOXS embedded computer
;
; Beschreibung: Include-Datei fr die Printscreen- (Screendump-)Funktion
;
; Version     : 02.12.2009
;
; Autor       : Adrian Furrer
;
;-------------------------------------------------------------------
; (c) 2009      S-TEC electronics AG
;-------------------------------------------------------------------


;___DEFINITIONEN___________________________________________________________________________
CONST PRINTSCREEN_X = 10
CONST PRINTSCREEN_Y = 480 - 30
CONST PRINTSCREEN_W = 45
CONST PRINTSCREEN_H = 20

CONST PRINTSCREEN_FILENAME = 'C:/OCN7/DUMP/PRTSC' ; '001.EGI' o.. wird automatisch generiert
CONST PRINTSCREEN_TEXT_UP = 'PRTSC'
CONST PRINTSCREEN_TEXT_DN = '.....'

CONST PRINTSCREEN_COLOR_TEXT = white
CONST PRINTSCREEN_COLOR_BACK = black


;___GLOBALES_______________________________________________________________________________
INTEGER PRINTSCREEN.fileexists.I = false
INTEGER PRINTSCREEN.filecounter.I = 1
STRING[256] PRINTSCREEN.filename.$


;___FUNKTIONEN_____________________________________________________________________________

;///////////////////////////////////////////////////////////////////
;// Button zeichnen
;///////////////////////////////////////////////////////////////////
SUB PrintScreen_Init

  ; Button zeichnen und HotSpot erstellen
  eI.HS_Tag := 0
  CallSubroutine(PrintScreen_Event)
  eI.HotSpotTag := 1
  HotSpot.Install(NIL, NIL, PrintScreen_Event, NIL)

ENDSUB ; PrintScreen_Init
;///////////////////////////////////////////////////////////////////


;///////////////////////////////////////////////////////////////////
;// Button zeichnen
;///////////////////////////////////////////////////////////////////
SUB PrintScreen_Event

  Load.Geometry_XYWH(PRINTSCREEN_X, PRINTSCREEN_Y, PRINTSCREEN_W, PRINTSCREEN_H)
  IF eI.HS_Tag == 0 THEN
    ; Button (Up) zeichnen
    Display.Prepare()
    Fill.LabelParameter(PrintScreen_Style_Up)
    Label.Text(PRINTSCREEN_TEXT_UP)
    Display.Show()
  ELSE
    ; Button (Down) zeichnen
    Display.Prepare()
    Fill.LabelParameter(PrintScreen_Style_Dn)
    Label.Text(PRINTSCREEN_TEXT_DN)
    Display.Show()

    ; Dateiname generieren
    REPEAT
      ; Dateiname zusammenstellen
      Str.Copy(PRINTSCREEN.filename.$, PRINTSCREEN_FILENAME)
      eI.FillChar := "0"
      Str.Cvt_Integer(PRINTSCREEN.filename.$, PRINTSCREEN.filecounter.I, 3)
      eI.FillChar := " "	; zurck Standardwert
      Str.Concat(PRINTSCREEN.filename.$, '.EGI')
  
      ; Prfen ob Datei schon vorhanden ist
      File.FileExists(PRINTSCREEN.filename.$, PRINTSCREEN.fileexists.I)
      IF PRINTSCREEN.fileexists.I == 1 THEN
        Math.INC_Integer(PRINTSCREEN.filecounter.I)
      ENDIF
    UNTIL PRINTSCREEN.fileexists.I == 0

    ; Screenshot erstellen
    File.ScreenDump(PRINTSCREEN.filename.$)

    ; Button (Up) zeichnen
    Display.Prepare()
    Fill.LabelParameter(PrintScreen_Style_Up)
    Label.Text(PRINTSCREEN_TEXT_UP)
    Display.Show()
  ENDIF

ENDSUB ; PrintScreen_Event
;///////////////////////////////////////////////////////////////////


SUB PrintScreen_Styles

PrintScreen_Style_Up:
  INLINEWORDS	(no_change)					; entspricht eI.Pos_X1
  INLINEWORDS	(no_change)					; entspricht eI.Pos_Y1
  INLINEWORDS	(no_change)					; entspricht eI.Width
  INLINEWORDS	(no_change)					; entspricht eI.Height
  INLINEWORDS	(0)						; entspricht eI.SpaceLeft
  INLINEWORDS	(0)						; entspricht eI.SpaceRight
  INLINEWORDS	(1)	       				; entspricht eI.HorizontalAdjust
  INLINEWORDS	(1)		       			; entspricht eI.VerticalAdjust
  INLINEWORDS	(PRINTSCREEN_COLOR_BACK)			; entspricht eI.FillColor
  INLINEWORDS	(as_FillColor)				; entspricht eI.BackColor
  INLINEWORDS	(as_FillColor)				; entspricht eI.LineColor
  INLINEWORDS	(PRINTSCREEN_COLOR_TEXT)			; entspricht eI.TextColor
  INLINEWORDS	(Pos_center)					; entspricht eI.Position
  INLINEWORDS	(Orientation_0deg)				; entspricht eI.Orientation
  INLINEWORDS	(normal)					; entspricht eI.Appearance
  INLINEWORDS	(border_color_button_soft_raised_big)	; entspricht eI.BorderStyle
  INLINEWORDS	(Font_System_9bd)				; entspricht eI.FontNumber
  INLINEWORDS	(as_Skin_FormBodyColor)			; entspricht eI.BackGroundColor

PrintScreen_Style_Dn:
  INLINEWORDS	(no_change)					; entspricht eI.Pos_X1
  INLINEWORDS	(no_change)					; entspricht eI.Pos_Y1
  INLINEWORDS	(no_change)					; entspricht eI.Width
  INLINEWORDS	(no_change)					; entspricht eI.Height
  INLINEWORDS	(0)						; entspricht eI.SpaceLeft
  INLINEWORDS	(0)						; entspricht eI.SpaceRight
  INLINEWORDS	(1)	       				; entspricht eI.HorizontalAdjust
  INLINEWORDS	(1)		       			; entspricht eI.VerticalAdjust
  INLINEWORDS	(PRINTSCREEN_COLOR_BACK)			; entspricht eI.FillColor
  INLINEWORDS	(as_FillColor)				; entspricht eI.BackColor
  INLINEWORDS	(as_FillColor)				; entspricht eI.LineColor
  INLINEWORDS	(PRINTSCREEN_COLOR_TEXT)			; entspricht eI.TextColor
  INLINEWORDS	(Pos_center)					; entspricht eI.Position
  INLINEWORDS	(Orientation_0deg)				; entspricht eI.Orientation
  INLINEWORDS	(normal)					; entspricht eI.Appearance
  INLINEWORDS	(border_color_button_soft_sunk_big)	; entspricht eI.BorderStyle
  INLINEWORDS	(Font_System_9bd)				; entspricht eI.FontNumber
  INLINEWORDS	(as_Skin_FormBodyColor)			; entspricht eI.BackGroundColor

ENDSUB
